@@ -17,3 +17,7 @@ insight::print_md
 #' @importFrom insight print_html
 #' @export
 insight::print_html
+
+#' @importFrom insight display
+#' @export
+insight::display
